- **Plugins**
  - [Bytes](plugins/bytes.md)
  - [Comments](plugins/comments.md)
  - [Entries](plugins/entries.md)
  - [Functions](plugins/functions.md)
  - [Names](plugins/names.md)
  - [Segments](plugins/segments.md)
  - [Server](plugins/server.md)
  - [Strings](plugins/strings.md)
  - [Types](plugins/types.md)
  - [Xrefs](plugins/xrefs.md)